/* --------------------------------------------------------

   Project:
      External_Ballistics

    Purpose:
      Simulates the flight of a round ball

   Author:
      Stephen C. Wardlaw, M.D.
      IVDx Consulting
      Highrock
      Lyme, CT 06371
      <swardlaw@ivdx.com>

   Edit History:
      30 March, 2011

 -------------------------------------------------------- */
#ifndef EXTERNAL_BALLISTICS_H
#define EXTERNAL_BALLISTICS_H

#include <QtGui/QMainWindow>
#include "ui_external_ballistics.h"

class External_Ballistics : public QMainWindow
{
	Q_OBJECT

public:
	External_Ballistics(QWidget *parent = 0, Qt::WFlags flags = 0);
	~External_Ballistics();

private slots:
	void
		aimChanged();

	void
		altitudeChanged(int index);

	void
		caliberChanged();

	void
		createPressureCurve();

	void
		mvChanged();

	void
		sightHeightChanged();

	void
		tempChanged();

	void
		weightChanged();

	void
		windChanged();

	void
		fireClicked();

private:	// Methods

double
	calcBallWeight(double caliber);

void
	calcRelDensity();

void
	calculate();

void
	doOutputLine(int index);

double
	lapsedTemp(double alt);

QString
	makeFileName();

double	// Retardation value
	rValue(double vel);

void
	showInput();

void
	showLine(QString line);

void
	showOutput();

private:	// Data
	QVector<double> mVelocity;
	QVector<double>	mDrop;
	QVector<double>	mDrift;
	QVector<double> mTof;


	double	mCaliber;
	double	mWeight;
	double	mAimPoint;
	double	mSightHeight;
	double	mMuzzleVelocity;
	double	mXWind;
	double	mSlope;
	double	mTemp;
	double	mRelDensity;	// Relative air density

	Ui::External_BallisticsClass ui;
};

#endif // EXTERNAL_BALLISTICS_H
